@@ -3,8 +3,8 @@
 /**
  * @file controllers/grid/catalogEntry/MarketsGridHandler.inc.php
  *
- * Copyright (c) 2014-2020 Simon Fraser University
- * Copyright (c) 2000-2020 John Willinsky
+ * Copyright (c) 2014-2021 Simon Fraser University
+ * Copyright (c) 2000-2021 John Willinsky
  * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @class MarketsGridHandler
@@ -127,7 +127,7 @@ class MarketsGridHandler extends GridHandler {
 		// Retrieve the associated publication format for this grid.
 		$marketId = (int) $request->getUserVar('marketId'); // set if editing or deleting a market entry
 
-		if ($marketId != '') {
+		if ($marketId) {
 			$marketDao = DAORegistry::getDAO('MarketDAO'); /* @var $marketDao MarketDAO */
 			$market = $marketDao->getById($marketId, $this->getPublication()->getId());
 			if ($market) {
@@ -338,19 +338,15 @@ class MarketsGridHandler extends GridHandler {
 
 		$marketDao = DAORegistry::getDAO('MarketDAO'); /* @var $marketDao MarketDAO */
 		$market = $marketDao->getById($marketId, $this->getPublication()->getId());
-		if ($market != null) { // authorized
-
-			$result = $marketDao->deleteObject($market);
-
-			if ($result) {
-				$currentUser = $request->getUser();
-				$notificationMgr = new NotificationManager();
-				$notificationMgr->createTrivialNotification($currentUser->getId(), NOTIFICATION_TYPE_SUCCESS, array('contents' => __('notification.removedMarket')));
-				return DAO::getDataChangedEvent();
-			} else {
-				return new JSONMessage(false, __('manager.setup.errorDeletingItem'));
-			}
+		if (!$market) {
+			return new JSONMessage(false, __('manager.setup.errorDeletingItem'));
 		}
+
+		$marketDao->deleteObject($market);
+		$currentUser = $request->getUser();
+		$notificationMgr = new NotificationManager();
+		$notificationMgr->createTrivialNotification($currentUser->getId(), NOTIFICATION_TYPE_SUCCESS, array('contents' => __('notification.removedMarket')));
+		return DAO::getDataChangedEvent();
 	}
 }
 
