@@ -3,8 +3,8 @@
 /**
  * @file pages/manageCatalog/ManageCatalogHandler.inc.php
  *
- * Copyright (c) 2014-2020 Simon Fraser University
- * Copyright (c) 2003-2020 John Willinsky
+ * Copyright (c) 2014-2021 Simon Fraser University
+ * Copyright (c) 2003-2021 John Willinsky
  * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @class ManageCatalogHandler
@@ -16,6 +16,10 @@
 import('classes.handler.Handler');
 
 class ManageCatalogHandler extends Handler {
+
+	/** @copydoc PKPHandler::_isBackendPage */
+	var $_isBackendPage = true;
+
 	/**
 	 * Constructor
 	 */
@@ -110,7 +114,7 @@ class ManageCatalogHandler extends Handler {
 		]);
 
 		$templateMgr = TemplateManager::getManager($request);
-		$templateMgr->assign('catalogListData', [
+		$templateMgr->setState([
 			'components' => [
 				'catalog' => $catalogList->getConfig()
 			]
