@@ -3,8 +3,8 @@
 /**
  * @file plugins/metadata/dc11/filter/Dc11SchemaPublicationFormatAdapter.inc.php
  *
- * Copyright (c) 2014-2020 Simon Fraser University
- * Copyright (c) 2000-2020 John Willinsky
+ * Copyright (c) 2014-2021 Simon Fraser University
+ * Copyright (c) 2000-2021 John Willinsky
  * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @class Dc11SchemaPublicationFormatAdapter
@@ -77,11 +77,8 @@ class Dc11SchemaPublicationFormatAdapter extends MetadataDataObjectAdapter {
 		$dc11Description = $this->instantiateMetadataDescription();
 
 		// Title
-		$titles = array();
-		foreach ($monograph->getTitle(null) as $titleLocale => $title) {
-			$titles[$titleLocale] = $monograph->getFullTitle($titleLocale);
-		}
-		$this->_addLocalizedElements($dc11Description, 'dc:title', $titles);
+	        $publication = $monograph->getCurrentPublication();
+		$this->_addLocalizedElements($dc11Description, 'dc:title', $publication->getFullTitles());
 
 		// Creator
 		$authors = $monograph->getAuthors();
@@ -100,8 +97,8 @@ class Dc11SchemaPublicationFormatAdapter extends MetadataDataObjectAdapter {
 		$submissionSubjectDao = DAORegistry::getDAO('SubmissionSubjectDAO'); /* @var $submissionSubjectDao SubmissionSubjectDAO */
 		$supportedLocales = array_keys(AppLocale::getSupportedFormLocales());
 		$subjects = array_merge_recursive(
-			(array) $submissionKeywordDao->getKeywords($monograph->getId(), $supportedLocales),
-			(array) $submissionSubjectDao->getSubjects($monograph->getId(), $supportedLocales)
+			(array) $submissionKeywordDao->getKeywords($publication->getId(), $supportedLocales),
+			(array) $submissionSubjectDao->getSubjects($publication->getId(), $supportedLocales)
 		);
 		$this->_addLocalizedElements($dc11Description, 'dc:subject', $subjects);
 
@@ -111,7 +108,7 @@ class Dc11SchemaPublicationFormatAdapter extends MetadataDataObjectAdapter {
 		// Publisher
 		$publisherInstitution = $press->getSetting('publisherInstitution');
 		if (!empty($publisherInstitution)) {
-			$publishers = array($press->getPrimaryLocale() => $publisherInstitution);
+			$publishers = [$press->getPrimaryLocale() => $publisherInstitution];
 		} else {
 			$publishers = $press->getName(null); // Default
 		}
@@ -135,7 +132,7 @@ class Dc11SchemaPublicationFormatAdapter extends MetadataDataObjectAdapter {
 
 		// Type
 		$types = array_merge_recursive(
-			array(AppLocale::getLocale() => __('rt.metadata.pkp.dctype')),
+			[AppLocale::getLocale() => __('rt.metadata.pkp.dctype')],
 			(array) $monograph->getType(null)
 		);
 		$this->_addLocalizedElements($dc11Description, 'dc:type', $types);
@@ -149,9 +146,9 @@ class Dc11SchemaPublicationFormatAdapter extends MetadataDataObjectAdapter {
 		}
 
 		// Identifier: URL
+		$request = Application::get()->getRequest();
 		if (is_a($monograph, 'Submission')) {
-			$request = Application::get()->getRequest();
-			$dc11Description->addStatement('dc:identifier', $request->url($press->getPath(), 'catalog', 'book', array($monograph->getId())));
+			$dc11Description->addStatement('dc:identifier', $request->url($press->getPath(), 'catalog', 'book', [$monograph->getId()]));
 		}
 
 		// Public idntifiers (e.g. DOI, URN)
@@ -180,24 +177,22 @@ class Dc11SchemaPublicationFormatAdapter extends MetadataDataObjectAdapter {
 		$this->_addLocalizedElements($dc11Description, 'dc:source', $sources);
 
 		// Language
-		$submissionLanguage = $publication->getData('locale');
+		$submissionLanguage = $monograph->getData('locale');
 		if (!empty($submissionLanguage)) {
 			$dc11Description->addStatement('dc:language', AppLocale::getIso3FromLocale($submissionLanguage));
 		}
 
 		// Relation   (Add publication file format to monograph / edited volume)
-		$publicationFormats = $publication->getData('publicationFormats');
-		$availableFiles = array_filter(
-			DAORegistry::getDAO('SubmissionFileDAO')->getLatestRevisions($monograph->getId(), null, null),
-			function ($a) {
-				return $a->getDirectSalesPrice() !== null && $a->getAssocType() == ASSOC_TYPE_PUBLICATION_FORMAT;
-			}
-		);
+		$pubFormatFiles = Services::get('submissionFile')->getMany([
+			'submissionIds' => [$monograph->getId()],
+			'assocTypes' => [ASSOC_TYPE_PUBLICATION_FORMAT]
+		]);
 
-		foreach ($availableFiles as $file) {
-			foreach ($publicationFormats as $format) {
-				if ($file->getAssocId() == $format->getId()) {
-					$relation = $request->url($press->getName(), 'catalog', 'view', array($monograph->getId(), $publicationFormat->getId(), $file->getId() . '-' . $file->getRevision()));
+
+		foreach ($pubFormatFiles as $file) {
+			{
+				if ($file->getData('assocId') == $publicationFormat->getData('id')) {
+					$relation = $request->url($press->getData('urlPath'), 'catalog', 'view', [$monograph->getId(), $publicationFormat->getId(), $file->getId()]);
 					$dc11Description->addStatement('dc:relation', $relation);
 				}
 			}
@@ -213,7 +208,7 @@ class Dc11SchemaPublicationFormatAdapter extends MetadataDataObjectAdapter {
 			$dc11Description->addStatement('dc:rights', $salesRight->getNameForONIXCode());
 		}
 
-		Hookregistry::call('Dc11SchemaPublicationFormatAdapter::extractMetadataFromDataObject', array(&$this, $monograph, $press, &$dc11Description));
+		Hookregistry::call('Dc11SchemaPublicationFormatAdapter::extractMetadataFromDataObject', [&$this, $monograph, $press, &$dc11Description]);
 
 		return $dc11Description;
 	}
@@ -224,7 +219,7 @@ class Dc11SchemaPublicationFormatAdapter extends MetadataDataObjectAdapter {
 	 */
 	function getDataObjectMetadataFieldNames($translated = true) {
 		// All DC fields are mapped.
-		return array();
+		return [];
 	}
 
 
@@ -239,7 +234,7 @@ class Dc11SchemaPublicationFormatAdapter extends MetadataDataObjectAdapter {
 	 */
 	function _addLocalizedElements(&$description, $propertyName, $localizedValues) {
 		foreach(stripAssocArray((array) $localizedValues) as $locale => $values) {
-			if (is_scalar($values)) $values = array($values);
+			if (is_scalar($values)) $values = [$values];
 			foreach($values as $value) {
 				$description->addStatement($propertyName, $value, $locale);
 				unset($value);
